@@ -8,10 +8,14 @@ template repository is available at https://github.com/mlflow/mlp-regression-tem
 :py:class:`RegressionPipeline API Documentation <RegressionPipeline>` provides instructions for
 executing the pipeline and inspecting its results.
 
-The pipeline contains the following sequential steps:
+The training pipeline contains the following sequential steps:
 
 **ingest** -> **split** -> **transform** -> **train** -> **evaluate** -> **register**
 
+The batch scoring pipeline contains the following sequential steps:
+
+**ingest** -> **predict**
+
 The pipeline steps are defined as follows:
 
    - **ingest**
@@ -87,6 +91,9 @@ The pipeline steps are defined as follows:
                 always registered with the MLflow Model Registry when the **register** step is
                 executed.
 
+    - **predict**
+      - The **predict** step
+
 .. |'split' step definition in pipeline.yaml| replace:: `'split' step definition in pipeline.yaml <https://github.com/mlflow/mlp-regression-template/blob/35f6f32c7a89dc655fbcfcf731cc1da4685a8ebb/pipeline.yaml#L36-L40>`__
 .. |'register' step definition of pipeline.yaml| replace:: `'register' step definition of pipeline.yaml <https://github.com/mlflow/mlp-regression-template/blob/35f6f32c7a89dc655fbcfcf731cc1da4685a8ebb/pipeline.yaml#L57-L63>`__
 .. |'data' section in pipeline.yaml| replace:: `'data' section in pipeline.yaml <https://github.com/mlflow/mlp-regression-template/blob/35f6f32c7a89dc655fbcfcf731cc1da4685a8ebb/pipeline.yaml#L15-L32>`__
@@ -105,7 +112,7 @@ import logging
 from mlflow.pipelines.regression.v1 import dag_help_strings
 from mlflow.tracking.client import MlflowClient
 from mlflow.pipelines.pipeline import _BasePipeline
-from mlflow.pipelines.steps.ingest import IngestStep
+from mlflow.pipelines.steps.ingest import IngestStep, IngestScoringStep
 from mlflow.pipelines.steps.split import (
     SplitStep,
     _OUTPUT_TRAIN_FILE_NAME,
@@ -115,6 +122,10 @@ from mlflow.pipelines.steps.split import (
 from mlflow.pipelines.steps.transform import TransformStep
 from mlflow.pipelines.steps.train import TrainStep
 from mlflow.pipelines.steps.evaluate import EvaluateStep
+from mlflow.pipelines.steps.predict import (
+    PredictStep,
+    _SCORED_OUTPUT_FILE_NAME,
+)
 from mlflow.pipelines.steps.register import RegisterStep, RegisteredModelVersionInfo
 from mlflow.pipelines.step import BaseStep
 from typing import List, Any, Optional
@@ -135,10 +146,14 @@ class RegressionPipeline(_BasePipeline):
     developing models using scikit-learn and frameworks that integrate with scikit-learn,
     such as the ``XGBRegressor`` API from XGBoost. The corresponding pipeline
     template repository is available at https://github.com/mlflow/mlp-regression-template.
-    The pipeline contains the following sequential steps:
+    The training pipeline contains the following sequential steps:
 
     **ingest** -> **split** -> **transform** -> **train** -> **evaluate** -> **register**
 
+    while the batch scoring pipeline contains this set of sequential steps:
+
+    **ingest_scoring** -> **predict**
+
     .. code-block:: python
         :caption: Example
 
@@ -159,11 +174,59 @@ class RegressionPipeline(_BasePipeline):
         regression_pipeline.inspect(step="evaluate")
     """
 
-    _PIPELINE_STEPS = (IngestStep, SplitStep, TransformStep, TrainStep, EvaluateStep, RegisterStep)
+    _TRAIN_DAG_NAME = "train_dag"
+    _TRAIN_DAG_STEPS = (
+        # Training data ingestion DAG
+        IngestStep,
+        # Model training DAG
+        SplitStep,
+        TransformStep,
+        TrainStep,
+        EvaluateStep,
+        RegisterStep,
+    )
 
-    def _get_step_classes(self) -> List[BaseStep]:
+    _SCORING_DAG_NAME = "scoring_dag"
+    _SCORING_DAG_STEPS = (
+        # Batch scoring DAG
+        IngestScoringStep,
+        PredictStep,
+    )
+
+    _PIPELINE_STEPS = _TRAIN_DAG_STEPS + _SCORING_DAG_STEPS
+
+    _STEPS_SUBGRAPH_MAP = dict()
+    for _step_class in _TRAIN_DAG_STEPS:
+        _STEPS_SUBGRAPH_MAP[_step_class] = _TRAIN_DAG_NAME
+    for _step_class in _SCORING_DAG_STEPS:
+        _STEPS_SUBGRAPH_MAP[_step_class] = _SCORING_DAG_NAME
+
+    _SUBGRAPH_INDICES_MAP = {
+        _TRAIN_DAG_NAME: (
+            _PIPELINE_STEPS.index(_TRAIN_DAG_STEPS[0]),
+            _PIPELINE_STEPS.index(_TRAIN_DAG_STEPS[-1]),
+        ),
+        _SCORING_DAG_NAME: (
+            _PIPELINE_STEPS.index(_SCORING_DAG_STEPS[0]),
+            _PIPELINE_STEPS.index(_SCORING_DAG_STEPS[-1]),
+        ),
+    }
+
+    _DEFAULT_STEP_INDEX = _PIPELINE_STEPS.index(RegisterStep)
+
+    def _get_step_classes(self):
         return self._PIPELINE_STEPS
 
+    def _get_subgraph_for_target_step(self, target_step: BaseStep) -> List[BaseStep]:
+        target_step_class = type(target_step)
+
+        subgraph_name = self._STEPS_SUBGRAPH_MAP[target_step_class]
+        s, e = self._SUBGRAPH_INDICES_MAP[subgraph_name]
+        return self._steps[s : e + 1]
+
+    def _get_default_step(self) -> BaseStep:
+        return self._steps[self._DEFAULT_STEP_INDEX]
+
     def _get_pipeline_dag_file(self) -> str:
         import jinja2
 
@@ -258,6 +321,10 @@ class RegressionPipeline(_BasePipeline):
                     "help_string": dag_help_strings.REGISTERED_MODEL_VERSION,
                     "help_string_type": "text",
                 },
+                "predict_step_help": {
+                    "help_string": dag_help_strings.PREDICT_STEP,
+                    "help_string_type": "text",
+                },
             }
         )
 
@@ -281,9 +348,13 @@ class RegressionPipeline(_BasePipeline):
                      its dependencies are executed sequentially. If a step is not specified, the
                      entire pipeline is executed. Supported steps, in their order of execution, are:
 
-                     - ``"ingest"``: resolves the dataset specified by the ``data`` section in the
-                       pipeline's configuration file (``pipeline.yaml``) and converts it to parquet
-                       format.
+                     - ``"ingest"``: resolves the dataset specified by the ``data/training`` section
+                       in the pipeline's configuration file (``pipeline.yaml``) and converts it to
+                       parquet format.
+
+                     - ``"ingest_scoring"``: resolves the dataset specified by the ``data/scoring``
+                       section in the pipeline's configuration file (``pipeline.yaml``) and converts
+                       it to parquet format.
 
                      - ``"split"``: splits the ingested dataset produced by the **ingest** step into
                        a training dataset for model training, a validation dataset for model
@@ -317,6 +388,9 @@ class RegressionPipeline(_BasePipeline):
                        indicated by the ``'VALIDATED'`` status), registers the model pipeline
                        created by the **train** step to the MLflow Model Registry.
 
+                     - ``"predict"``: uses the ingested dataset for scoring created by the
+                       **ingest_scoring** step and applies the specified model to the dataset.
+
         .. code-block:: python
             :caption: Example
 
@@ -357,6 +431,9 @@ class RegressionPipeline(_BasePipeline):
                          - ``"test_data"``: returns the test dataset created in the **split** step
                            as a pandas DataFrame.
 
+                         - ``"ingested_scoring_data"``: returns the scoring dataset created in the
+                           **ingest_scoring** step as a pandas DataFrame.
+
                          - ``"transformed_training_data"``: returns the transformed training dataset
                            created in the **transform** step as a pandas DataFrame.
 
@@ -379,6 +456,9 @@ class RegressionPipeline(_BasePipeline):
                            :py:class:`ModelVersion <mlflow.entities.model_registry.ModelVersion>`
                            created by the **register** step.
 
+                         - ``"scored_data"``: returns the scored dataset created in the
+                           **predict** step as a pandas DataFrame.
+
         :return: An object representation of the artifact corresponding to the specified name,
                  as described in the ``artifact_name`` parameter docstring. If the artifact is
                  not present because its corresponding step has not been executed or its output
@@ -400,14 +480,16 @@ class RegressionPipeline(_BasePipeline):
         """
         import mlflow.pyfunc
 
-        ingest_step, split_step, transform_step, train_step, _, register_step = self._steps
-
-        ingest_output_dir = get_step_output_path(self._pipeline_root_path, ingest_step.name, "")
-        split_output_dir = get_step_output_path(self._pipeline_root_path, split_step.name, "")
-        transform_output_dir = get_step_output_path(
-            self._pipeline_root_path, transform_step.name, ""
-        )
-        train_output_dir = get_step_output_path(self._pipeline_root_path, train_step.name, "")
+        (
+            ingest_step,
+            split_step,
+            transform_step,
+            train_step,
+            _,
+            register_step,
+            ingest_scoring_step,
+            predict_step,
+        ) = self._steps
 
         def log_artifact_not_found_warning(artifact_name, step_name):
             _logger.warning(
@@ -416,6 +498,7 @@ class RegressionPipeline(_BasePipeline):
             )
 
         def read_run_id():
+            train_output_dir = get_step_output_path(self._pipeline_root_path, train_step.name, "")
             run_id_file_path = os.path.join(train_output_dir, "run_id")
             if os.path.exists(run_id_file_path):
                 with open(run_id_file_path, "r") as f:
@@ -426,54 +509,36 @@ class RegressionPipeline(_BasePipeline):
         train_step_tracking_uri = train_step.tracking_config.tracking_uri
         pipeline_root_path = get_pipeline_root_path()
 
-        def read_dataframe(artifact_name, output_dir, file_name, step_name):
+        def read_dataframe_from_path(artifact_path, step_name):
             import pandas as pd
 
-            data_path = os.path.join(output_dir, file_name)
-            if os.path.exists(data_path):
-                return pd.read_parquet(data_path)
+            if os.path.exists(artifact_path):
+                return pd.read_parquet(artifact_path)
             else:
                 log_artifact_not_found_warning(artifact_name, step_name)
                 return None
 
+        artifact_path = self._get_artifact_path(
+            artifact_name
+        )  # path may or may not exist, error handling is in this function
+
         if artifact_name == "ingested_data":
-            return read_dataframe(
-                "ingested_data",
-                ingest_output_dir,
-                IngestStep._DATASET_OUTPUT_NAME,
-                ingest_step.name,
-            )
+            return read_dataframe_from_path(artifact_path, ingest_step.name)
 
         elif artifact_name == "training_data":
-            return read_dataframe(
-                "training_data", split_output_dir, _OUTPUT_TRAIN_FILE_NAME, split_step.name
-            )
+            return read_dataframe_from_path(artifact_path, split_step.name)
 
         elif artifact_name == "validation_data":
-            return read_dataframe(
-                "validation_data", split_output_dir, _OUTPUT_VALIDATION_FILE_NAME, split_step.name
-            )
+            return read_dataframe_from_path(artifact_path, split_step.name)
 
         elif artifact_name == "test_data":
-            return read_dataframe(
-                "test_data", split_output_dir, _OUTPUT_TEST_FILE_NAME, split_step.name
-            )
+            return read_dataframe_from_path(artifact_path, split_step.name)
 
         elif artifact_name == "transformed_training_data":
-            return read_dataframe(
-                "transformed_training_data",
-                transform_output_dir,
-                "transformed_training_data.parquet",
-                transform_step.name,
-            )
+            return read_dataframe_from_path(artifact_path, transform_step.name)
 
         elif artifact_name == "transformed_validation_data":
-            return read_dataframe(
-                "transformed_validation_data",
-                transform_output_dir,
-                "transformed_validation_data.parquet",
-                transform_step.name,
-            )
+            return read_dataframe_from_path(artifact_path, transform_step.name)
 
         elif artifact_name == "model":
             run_id = read_run_id()
@@ -505,16 +570,8 @@ class RegressionPipeline(_BasePipeline):
                 return None
 
         elif artifact_name == "registered_model_version":
-            register_output_dir = get_step_output_path(
-                self._pipeline_root_path, register_step.name, ""
-            )
-            registered_model_info_path = os.path.join(
-                register_output_dir, "registered_model_version.json"
-            )
-            if os.path.exists(registered_model_info_path):
-                registered_model_info = RegisteredModelVersionInfo.from_json(
-                    path=registered_model_info_path
-                )
+            if os.path.exists(artifact_path):
+                registered_model_info = RegisteredModelVersionInfo.from_json(path=artifact_path)
                 with _use_tracking_uri(train_step_tracking_uri, pipeline_root_path):
                     return MlflowClient().get_model_version(
                         name=registered_model_info.name, version=registered_model_info.version
@@ -523,6 +580,82 @@ class RegressionPipeline(_BasePipeline):
                 log_artifact_not_found_warning("registered_model_version", register_step.name)
                 return None
 
+        elif artifact_name == "ingested_scoring_data":
+            return read_dataframe_from_path(artifact_path, ingest_scoring_step.name)
+
+        elif artifact_name == "scored_data":
+            return read_dataframe_from_path(artifact_path, predict_step.name)
+
+        else:
+            raise MlflowException(
+                f"The artifact with name '{artifact_name}' is not supported.",
+                error_code=INVALID_PARAMETER_VALUE,
+            )
+
+    def _get_artifact_path(self, artifact_name: str) -> Optional[str]:
+        """
+        Returns a path to an artifact, which may or may not exist depending on whether or not the
+        corresponding pipeline step has been run.
+        """
+        (
+            ingest_step,
+            split_step,
+            transform_step,
+            train_step,
+            _,
+            register_step,
+            ingest_scoring_step,
+            predict_step,
+        ) = self._steps
+
+        if artifact_name == "ingested_data":
+            ingest_output_dir = get_step_output_path(self._pipeline_root_path, ingest_step.name, "")
+            return os.path.join(ingest_output_dir, IngestStep._DATASET_OUTPUT_NAME)
+        elif artifact_name == "training_data":
+            split_output_dir = get_step_output_path(self._pipeline_root_path, split_step.name, "")
+            return os.path.join(split_output_dir, _OUTPUT_TRAIN_FILE_NAME)
+        elif artifact_name == "validation_data":
+            split_output_dir = get_step_output_path(self._pipeline_root_path, split_step.name, "")
+            return os.path.join(split_output_dir, _OUTPUT_VALIDATION_FILE_NAME)
+        elif artifact_name == "test_data":
+            split_output_dir = get_step_output_path(self._pipeline_root_path, split_step.name, "")
+            return os.path.join(split_output_dir, _OUTPUT_TEST_FILE_NAME)
+        elif artifact_name == "transformed_training_data":
+            transform_output_dir = get_step_output_path(
+                self._pipeline_root_path, transform_step.name, ""
+            )
+            return os.path.join(transform_output_dir, "transformed_training_data.parquet")
+        elif artifact_name == "transformed_validation_data":
+            transform_output_dir = get_step_output_path(
+                self._pipeline_root_path, transform_step.name, ""
+            )
+            return os.path.join(transform_output_dir, "transformed_validation_data.parquet")
+        elif artifact_name == "model":
+            train_output_dir = get_step_output_path(self._pipeline_root_path, train_step.name, "")
+            return os.path.join(train_output_dir, "model", "model.pkl")
+        elif artifact_name == "transformer":
+            transform_output_dir = get_step_output_path(
+                self._pipeline_root_path, transform_step.name, ""
+            )
+            return os.path.join(transform_output_dir, "transformer.pkl")
+        elif artifact_name == "run":
+            train_output_dir = get_step_output_path(self._pipeline_root_path, train_step.name, "")
+            return os.path.join(train_output_dir, "run_id")
+        elif artifact_name == "registered_model_version":
+            register_output_dir = get_step_output_path(
+                self._pipeline_root_path, register_step.name, ""
+            )
+            return os.path.join(register_output_dir, "registered_model_version.json")
+        elif artifact_name == "ingested_scoring_data":
+            ingest_scoring_output_dir = get_step_output_path(
+                self._pipeline_root_path, ingest_scoring_step.name, ""
+            )
+            return os.path.join(ingest_scoring_output_dir, IngestScoringStep._DATASET_OUTPUT_NAME)
+        elif artifact_name == "scored_data":
+            predict_output_dir = get_step_output_path(
+                self._pipeline_root_path, predict_step.name, ""
+            )
+            return os.path.join(predict_output_dir, _SCORED_OUTPUT_FILE_NAME)
         else:
             raise MlflowException(
                 f"The artifact with name '{artifact_name}' is not supported.",
