@@ -6,11 +6,13 @@ The passed int model is expected to have function:
 Input, expected in text/csv or application/json format,
 is parsed into pandas.DataFrame and passed to the model.
 
-Defines two endpoints:
+Defines three endpoints:
     /ping used for health check
+    /health (same as /ping)
     /invocations used for scoring
 """
 from collections import OrderedDict
+from typing import Tuple, Dict
 import flask
 import json
 import logging
@@ -24,10 +26,11 @@ import traceback
 # model's conda environment. The version of mlflow doing the serving (outside) and the version of
 # mlflow in the model's conda environment (inside) can differ. We should therefore keep mlflow
 # dependencies to the minimum here.
-# ALl of the mlfow dependencies below need to be backwards compatible.
+# ALl of the mlflow dependencies below need to be backwards compatible.
 from mlflow.exceptions import MlflowException
 from mlflow.types import Schema
 from mlflow.utils import reraise
+from mlflow.utils.file_utils import path_to_local_file_uri
 from mlflow.utils.proto_json_utils import (
     NumpyEncoder,
     _dataframe_from_json,
@@ -39,13 +42,10 @@ try:
     from mlflow.pyfunc import load_model, PyFuncModel
 except ImportError:
     from mlflow.pyfunc import load_pyfunc as load_model
-from mlflow.protos.databricks_pb2 import MALFORMED_REQUEST, BAD_REQUEST
+from mlflow.protos.databricks_pb2 import BAD_REQUEST
 from mlflow.server.handlers import catch_mlflow_exception
 
-try:
-    from StringIO import StringIO
-except ImportError:
-    from io import StringIO
+from io import StringIO
 
 _SERVER_MODEL_PATH = "__pyfunc_model_path__"
 
@@ -85,7 +85,7 @@ def infer_and_parse_json_input(json_input, schema: Schema = None):
                 "Failed to parse input from JSON. Ensure that input is a valid JSON"
                 " formatted string."
             ),
-            error_code=MALFORMED_REQUEST,
+            error_code=BAD_REQUEST,
         )
 
     if isinstance(decoded_input, list):
@@ -96,7 +96,8 @@ def infer_and_parse_json_input(json_input, schema: Schema = None):
                 return parse_tf_serving_input(decoded_input, schema=schema)
             except MlflowException as ex:
                 _handle_serving_error(
-                    error_message=(ex.message), error_code=MALFORMED_REQUEST,
+                    error_message=(ex.message),
+                    error_code=BAD_REQUEST,
                 )
         else:
             return parse_json_input(json_input=json_input, orient="split", schema=schema)
@@ -106,7 +107,7 @@ def infer_and_parse_json_input(json_input, schema: Schema = None):
                 "Failed to parse input from JSON. Ensure that input is a valid JSON"
                 " list or dictionary."
             ),
-            error_code=MALFORMED_REQUEST,
+            error_code=BAD_REQUEST,
         )
 
 
@@ -129,18 +130,23 @@ def parse_json_input(json_input, orient="split", schema: Schema = None):
                 " produced using the `pandas.DataFrame.to_json(..., orient='{orient}')`"
                 " method.".format(orient=orient)
             ),
-            error_code=MALFORMED_REQUEST,
+            error_code=BAD_REQUEST,
         )
 
 
-def parse_csv_input(csv_input):
+def parse_csv_input(csv_input, schema: Schema = None):
     """
     :param csv_input: A CSV-formatted string representation of a Pandas DataFrame, or a stream
                       containing such a string representation.
+    :param schema: Optional schema specification to be used during parsing.
     """
 
     try:
-        return pd.read_csv(csv_input)
+        if schema is None:
+            return pd.read_csv(csv_input)
+        else:
+            dtypes = dict(zip(schema.input_names(), schema.pandas_types()))
+            return pd.read_csv(csv_input, dtype=dtypes)
     except Exception:
         _handle_serving_error(
             error_message=(
@@ -148,7 +154,7 @@ def parse_csv_input(csv_input):
                 " a valid CSV-formatted Pandas DataFrame produced using the"
                 " `pandas.DataFrame.to_csv()` method."
             ),
-            error_code=MALFORMED_REQUEST,
+            error_code=BAD_REQUEST,
         )
 
 
@@ -173,7 +179,7 @@ def parse_split_oriented_json_input_to_numpy(json_input):
                 " produced using the `pandas.DataFrame.to_json(..., orient='split')`"
                 " method."
             ),
-            error_code=MALFORMED_REQUEST,
+            error_code=BAD_REQUEST,
         )
 
 
@@ -215,6 +221,7 @@ def init(model: PyFuncModel):
     input_schema = model.metadata.get_input_schema()
 
     @app.route("/ping", methods=["GET"])
+    @app.route("/health", methods=["GET"])
     def ping():  # pylint: disable=unused-variable
         """
         Determine if the container is working and healthy.
@@ -259,7 +266,7 @@ def init(model: PyFuncModel):
         if mime_type == CONTENT_TYPE_CSV and not content_format:
             data = flask.request.data.decode("utf-8")
             csv_input = StringIO(data)
-            data = parse_csv_input(csv_input=csv_input)
+            data = parse_csv_input(csv_input=csv_input, schema=input_schema)
         elif mime_type == CONTENT_TYPE_JSON and not content_format:
             json_str = flask.request.data.decode("utf-8")
             data = infer_and_parse_json_input(json_str, input_schema)
@@ -343,3 +350,43 @@ def _predict(model_uri, input_path, output_path, content_type, json_format):
 def _serve(model_uri, port, host):
     pyfunc_model = load_model(model_uri)
     init(pyfunc_model).run(port=port, host=host)
+
+
+def get_cmd(
+    model_uri: str, port: int = None, host: int = None, timeout: int = None, nworkers: int = None
+) -> Tuple[str, Dict[str, str]]:
+    local_uri = path_to_local_file_uri(model_uri)
+    timeout = timeout or 60
+    # NB: Absolute windows paths do not work with mlflow apis, use file uri to ensure
+    # platform compatibility.
+    if os.name != "nt":
+        args = [f"--timeout={timeout}"]
+        if port and host:
+            args.append(f"-b {host}:{port}")
+        elif host:
+            args.append(f"-b {host}")
+
+        if nworkers:
+            args.append(f"-w {nworkers}")
+
+        command = (
+            f"gunicorn {' '.join(args)} ${{GUNICORN_CMD_ARGS}}"
+            " -- mlflow.pyfunc.scoring_server.wsgi:app"
+        )
+    else:
+        args = []
+        if host:
+            args.append(f"--host={host}")
+
+        if port:
+            args.append(f"--port={port}")
+
+        command = (
+            f"waitress-serve {' '.join(args)} "
+            "--ident=mlflow mlflow.pyfunc.scoring_server.wsgi:app"
+        )
+
+    command_env = os.environ.copy()
+    command_env[_SERVER_MODEL_PATH] = local_uri
+
+    return command, command_env
