@@ -550,9 +550,9 @@ class SqlAlchemyStore(AbstractStore):
             # Convert to RegisteredModel entity first and then extract latest_versions
             latest_versions = sql_registered_model.to_mlflow_entity().latest_versions
             if stages is None or len(stages) == 0:
-                expected_stages = set([get_canonical_stage(stage) for stage in ALL_STAGES])
+                expected_stages = {get_canonical_stage(stage) for stage in ALL_STAGES}
             else:
-                expected_stages = set([get_canonical_stage(stage) for stage in stages])
+                expected_stages = {get_canonical_stage(stage) for stage in stages}
             return [mv for mv in latest_versions if mv.current_stage in expected_stages]
 
     @classmethod
