@@ -25,6 +25,7 @@ from mlflow.tracking.context import registry as context_registry
 from mlflow.tracking.default_experiment import registry as default_experiment_registry
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 from mlflow.utils import env
+from mlflow.utils.annotations import deprecated
 from mlflow.utils.autologging_utils import (
     is_testing,
     autologging_integration,
@@ -41,7 +42,6 @@ from mlflow.utils.mlflow_tags import (
     MLFLOW_EXPERIMENT_PRIMARY_METRIC_GREATER_IS_BETTER,
 )
 from mlflow.utils.validation import _validate_run_id, _validate_experiment_id_type
-from mlflow.utils.annotations import experimental
 
 
 if TYPE_CHECKING:
@@ -203,7 +203,8 @@ def start_run(
                           environment variable, ``MLFLOW_EXPERIMENT_ID`` environment variable,
                           or the default experiment as defined by the tracking server.
     :param run_name: Name of new run (stored as a ``mlflow.runName`` tag).
-                     Used only when ``run_id`` is unspecified.
+                     Used only when ``run_id`` is unspecified. If a new run is created and
+                     ``run_name`` is not specified, a unique name will be generated for the run.
     :param nested: Controls whether run is nested in parent run. ``True`` creates a nested run.
     :param tags: An optional dictionary of string keys and values to set as tags on the run.
                  If a run is being resumed, these tags are set on the resumed run. If a new run is
@@ -514,7 +515,7 @@ def get_run(run_id: str) -> Run:
     return MlflowClient().get_run(run_id)
 
 
-def log_param(key: str, value: Any) -> None:
+def log_param(key: str, value: Any) -> Any:
     """
     Log a parameter (e.g. model hyperparameter) under the current run. If no run is active,
     this method will create a new active run.
@@ -527,16 +528,19 @@ def log_param(key: str, value: Any) -> None:
                   All backend stores support values up to length 500, but some
                   may support larger values.
 
+    :return: the parameter value that is logged.
+
     .. code-block:: python
         :caption: Example
 
         import mlflow
 
         with mlflow.start_run():
-            mlflow.log_param("learning_rate", 0.01)
+            value = mlflow.log_param("learning_rate", 0.01)
+            assert value == 0.01
     """
     run_id = _get_or_start_run().info.run_id
-    MlflowClient().log_param(run_id, key, value)
+    return MlflowClient().log_param(run_id, key, value)
 
 
 def set_experiment_tag(key: str, value: Any) -> None:
@@ -999,6 +1003,7 @@ def get_experiment(experiment_id: str) -> Experiment:
         print("Artifact Location: {}".format(experiment.artifact_location))
         print("Tags: {}".format(experiment.tags))
         print("Lifecycle_stage: {}".format(experiment.lifecycle_stage))
+        print("Creation timestamp: {}".format(experiment.creation_time))
 
     .. code-block:: text
         :caption: Output
@@ -1007,6 +1012,7 @@ def get_experiment(experiment_id: str) -> Experiment:
         Artifact Location: file:///.../mlruns/0
         Tags: {}
         Lifecycle_stage: active
+        Creation timestamp: 1662004217511
     """
     return MlflowClient().get_experiment(experiment_id)
 
@@ -1030,6 +1036,7 @@ def get_experiment_by_name(name: str) -> Optional[Experiment]:
         print("Artifact Location: {}".format(experiment.artifact_location))
         print("Tags: {}".format(experiment.tags))
         print("Lifecycle_stage: {}".format(experiment.lifecycle_stage))
+        print("Creation timestamp: {}".format(experiment.creation_time))
 
     .. code-block:: text
         :caption: Output
@@ -1038,10 +1045,12 @@ def get_experiment_by_name(name: str) -> Optional[Experiment]:
         Artifact Location: file:///.../mlruns/0
         Tags: {}
         Lifecycle_stage: active
+        Creation timestamp: 1662004217511
     """
     return MlflowClient().get_experiment_by_name(name)
 
 
+@deprecated(alternative="search_experiments()")
 def list_experiments(
     view_type: int = ViewType.ACTIVE_ONLY,
     max_results: Optional[int] = None,
@@ -1063,7 +1072,6 @@ def list_experiments(
     return _paginate(pagination_wrapper_func, SEARCH_MAX_RESULTS_DEFAULT, max_results)
 
 
-@experimental
 def search_experiments(
     view_type: int = ViewType.ACTIVE_ONLY,
     max_results: Optional[int] = None,
@@ -1201,6 +1209,7 @@ def create_experiment(
         print("Artifact Location: {}".format(experiment.artifact_location))
         print("Tags: {}".format(experiment.tags))
         print("Lifecycle_stage: {}".format(experiment.lifecycle_stage))
+        print("Creation timestamp: {}".format(experiment.creation_time))
 
     .. code-block:: text
         :caption: Output
@@ -1210,6 +1219,7 @@ def create_experiment(
         Artifact Location: file:///.../mlruns
         Tags: {'version': 'v1', 'priority': 'P1'}
         Lifecycle_stage: active
+        Creation timestamp: 1662004217511
     """
     return MlflowClient().create_experiment(name, artifact_location, tags)
 
@@ -1233,13 +1243,14 @@ def delete_experiment(experiment_id: str) -> None:
         print("Name: {}".format(experiment.name))
         print("Artifact Location: {}".format(experiment.artifact_location))
         print("Lifecycle_stage: {}".format(experiment.lifecycle_stage))
-
+        print("Last Updated timestamp: {}".format(experiment.last_update_time))
     .. code-block:: text
         :caption: Output
 
         Name: New Experiment
         Artifact Location: file:///.../mlruns/2
         Lifecycle_stage: deleted
+        Last Updated timestamp: 1662004217511
     """
     MlflowClient().delete_experiment(experiment_id)
 
@@ -1334,7 +1345,7 @@ def search_runs(
     experiment_names: Optional[List[str]] = None,
 ) -> Union[List[Run], "pandas.DataFrame"]:
     """
-    Get a pandas DataFrame of runs that fit the search criteria.
+    Search for Runs that fit the specified criteria.
 
     :param experiment_ids: List of experiment IDs. Search can work with experiment IDs or
                            experiment names, but not both in the same call. Values other than
@@ -1521,6 +1532,7 @@ def search_runs(
         )
 
 
+@deprecated(alternative="search_runs()")
 def list_run_infos(
     experiment_id: str,
     run_view_type: int = ViewType.ACTIVE_ONLY,
@@ -1849,7 +1861,7 @@ def autolog(
     # this way, we do not send any errors to the user until we know they are using the library.
     # the post-import hook also retroactively activates for previously-imported libraries.
     for module in list(
-        set(LIBRARY_TO_AUTOLOG_FN.keys()) - set(["tensorflow", "keras", "pyspark", "pyspark.ml"])
+        set(LIBRARY_TO_AUTOLOG_FN.keys()) - {"tensorflow", "keras", "pyspark", "pyspark.ml"}
     ):
         register_post_import_hook(setup_autologging, module, overwrite=True)
 
