@@ -13,6 +13,8 @@ MLFLOW_PARENT_RUN_ID = "mlflow.parentRunId"
 MLFLOW_USER = "mlflow.user"
 MLFLOW_SOURCE_TYPE = "mlflow.source.type"
 MLFLOW_PIPELINE_TEMPLATE_NAME = "mlflow.pipeline.template.name"
+MLFLOW_PIPELINE_STEP_NAME = "mlflow.pipeline.step.name"
+MLFLOW_PIPELINE_PROFILE_NAME = "mlflow.pipeline.profile.name"
 MLFLOW_SOURCE_NAME = "mlflow.source.name"
 MLFLOW_GIT_COMMIT = "mlflow.source.git.commit"
 MLFLOW_GIT_BRANCH = "mlflow.source.git.branch"
