@@ -118,6 +118,62 @@ test_that("mlflow_list_experiments() works properly", {
   expect_identical(deleted_experiments$name, "foo1")
 })
 
+test_that("mlflow_search_experiments() works properly", {
+  mlflow_clear_test_dir("mlruns")
+  client <- mlflow_client()
+  ex1 <- mlflow_create_experiment(client = client, "foo1", "art_loc1")
+  ex2 <- mlflow_create_experiment(client = client, "foo2", "art_loc2")
+  ex3 <- mlflow_create_experiment(client = client, "foo3", "art_loc3")
+
+  mlflow_set_experiment_tag("expgroup", "group1", experiment_id = ex1)
+  mlflow_set_experiment_tag("expgroup", "group1", experiment_id = ex3)
+
+  allexperiments_result <- mlflow_search_experiments(client = client)
+  allexperiments <- allexperiments_result$experiments
+  expect_setequal(allexperiments$experiment_id, c("0", "1", "2", "3"))
+  expect_setequal(allexperiments$name, c("Default", "foo1", "foo2", "foo3"))
+  default_artifact_loc <- file.path(getwd(), "mlruns", "0", fsep = "/")
+  expect_setequal(allexperiments$artifact_location, c(default_artifact_loc,
+                                                      "art_loc1",
+                                                      "art_loc2",
+                                                      "art_loc3"))
+  expect_null(allexperiments_result$next_page_token)
+
+  ex1_result = mlflow_search_experiments(filter = "attribute.name = 'foo1'")
+  expect_setequal(ex1_result$experiments$experiment_id, c("1"))
+  expect_null(ex1_result$next_page_token)
+
+  exgroup1_result = mlflow_search_experiments(filter = "tags.expgroup = 'group1'")
+  expect_setequal(exgroup1_result$experiments$experiment_id, c("1", "3"))
+  expect_null(exgroup1_result$next_page_token)
+
+  mlflow_delete_experiment(experiment_id = "1")
+  deleted_experiments_result <- mlflow_search_experiments(experiment_view_type = "DELETED_ONLY")
+  expect_setequal(deleted_experiments_result$experiments$experiment_id, c("1"))
+  expect_null(deleted_experiments_result$next_page_token)
+
+  # By default, only active experiments should be returned
+  active_experiments_result <- mlflow_search_experiments()
+  expect_setequal(active_experiments_result$experiments$experiment_id, c("0", "2", "3"))
+  expect_null(active_experiments_result$next_page_token)
+
+  order_limit_result1 <- mlflow_search_experiments(
+    max_results = 2,
+    order_by = c("attribute.name desc"),
+    experiment_view_type="ALL",
+  )
+  expect_setequal(order_limit_result1$experiments$name, c("foo3", "foo2"))
+
+  order_limit_result2 <- mlflow_search_experiments(
+    max_results = 2,
+    order_by = c("attribute.name desc"),
+    page_token = order_limit_result1$next_page_token,
+    experiment_view_type="ALL",
+  )
+  expect_setequal(order_limit_result2$experiments$name, c("foo1", "Default"))
+  expect_null(order_limit_result2$next_page_token)
+})
+
 test_that("mlflow_set_experiment_tag() works correctly", {
   mlflow_clear_test_dir("mlruns")
   client <- mlflow_client()
